@@ -19,15 +19,19 @@ class Keybinder(gobject.GObject):
     def bind(self, keybinding):
         if self.bound:
             self.unbind()
-            
 
         logging.info('Binding Global shortcut %s to focus the deskbar' % keybinding)
-        self.bound = deskbar.core.keybinder.tomboy_keybinder_bind(keybinding, self.on_keyboard_shortcut)
-        self.prevbinding = keybinding
+        try:
+            self.bound = deskbar.core.keybinder.tomboy_keybinder_bind(keybinding, self.on_keyboard_shortcut)
+            self.prevbinding = keybinding
+        except KeyError:
+            # binding failed
+            self.bound = False
         
         return self.bound
                     
     def unbind(self):
+        logging.info('Unbinding Global shortcut %s to focus the deskbar' % self.prevbinding)
         try:
             deskbar.core.keybinder.tomboy_keybinder_unbind(self.prevbinding)
             self.bound = False
