@@ -84,7 +84,7 @@ class EpiphanyBookmarksHandler(EpiphanyHandler):
 
 class EpiphanySearchHandler(EpiphanyBookmarksHandler):
     
-    INFOS = {'icon': deskbar.core.Utils.load_icon('stock_bookmark'),
+    INFOS = {'icon': deskbar.core.Utils.load_icon('web-search.png'),
              "name": _("Web Searches (Epiphany)"),
              "description": _("Search the web via your browser's search settings"),
              "version": VERSION,
@@ -108,14 +108,13 @@ class EpiphanySearchHandler(EpiphanyBookmarksHandler):
             try:
                 b = shortcuts_to_smart_bookmarks_map[prefix]
                 text = query[x+1:]
-                return [BrowserSmartMatch(b.get_name()["name"], b.url, prefix, b, icon=b._icon, priority=self.get_priority())]
+                self._emit_query_ready(query, [BrowserSmartMatch(b.get_name(), b.url, prefix, b, icon=b._icon, priority=self.get_priority())] )
+                return
             except KeyError:
                 # Probably from the b = ... line.  Getting here
                 # means that there is no such shortcut.
                 pass
-        
-        self._emit_query_ready(query, smart_bookmarks )
-        
+        self._emit_query_ready(query, smart_bookmarks)
     def show_config(self, parent):
         on_customize_search_shortcuts(smart_bookmarks, shortcuts_to_smart_bookmarks_map)
         
