@@ -1,5 +1,6 @@
 import re
 import glob
+import os
 from os.path import join, expanduser
 from gettext import gettext as _
 from deskbar.defs import VERSION
@@ -30,6 +31,8 @@ class GenericAction(OpenWithApplicationAction):
     def activate(self, text=None):
         self._arguments += [text]
         OpenWithApplicationAction.activate(self, text)
+        # Restore old arguments
+        del self._arguments[-1]
         
     def get_verb(self):
         return self._verb
@@ -62,9 +65,9 @@ class GenericProgramMatch(deskbar.interfaces.Match):
             program = self._desktop.get_string("Exec")
             self.add_action( GenericAction(self.get_name(), program, self._args, verb) )
         else:
-            self.add_action( OpenDesktopFileAction(self.get_name(), self._desktop, self.desktop_file) )
+            self.add_action( OpenDesktopFileAction(self.get_name(), self._desktop, self.desktop_file, self._display_prog) )
 
-    def get_hash(self, text=None):
+    def get_hash(self):
         return "generic_"+self._display_prog
         
 class GnomeDictMatch(GenericProgramMatch):
@@ -126,7 +129,7 @@ class GnomeDictHandler(SpecialProgramHandler):
 
 class GnomeSearchHandler(SpecialProgramHandler):
     
-    INFOS = {'icon': deskbar.core.Utils.load_icon('gnome-searchtool'),
+    INFOS = {'icon': deskbar.core.Utils.load_icon('system-search'),
              'name': _("Files and Folders Search"),
              "description": _("Find files and folders by searching for a name pattern"),
              'version': VERSION}
@@ -164,6 +167,9 @@ class OpenPathProgramAction(deskbar.interfaces.Action):
         deskbar.interfaces.Action.__init__(self, name)
         self.use_terminal = use_terminal
         
+    def get_icon(self):
+        return "gtk-execute"
+        
     def activate(self, text=None):
         if self.use_terminal:
             try:
@@ -190,27 +196,30 @@ class OpenPathProgramAction(deskbar.interfaces.Action):
                 #No zenity, get out of the if, and launch without GUI
                 pass
         
-        spawn_async(text.split(" "))            
+        spawn_async(text.split(" "))
+        
+    def get_hash(self):
+        if self.use_terminal:
+            return self._name + "_terminal"
+        else:
+            return self._name
 
     def get_verb(self):
-        return _("Execute %s") % "<b>%(text)s</b>"
+        if self.use_terminal:
+            return _("Execute %s in terminal") % "<b>%(text)s</b>"
+        else:
+            return _("Execute %s") % "<b>%(text)s</b>"
 
 class PathProgramMatch(deskbar.interfaces.Match):
     
-    def __init__(self, name=None, use_terminal=False, priority=0, **args):
+    def __init__(self, name, command, priority=0, **args):
         deskbar.interfaces.Match.__init__(self, name=name, icon="gtk-execute", category="actions", **args)
-        self.use_terminal = use_terminal
         self.set_priority(self.get_priority() + EXACT_MATCH_PRIO)
-        self.add_action( OpenPathProgramAction(name, self.use_terminal) )
-        
-    def set_with_terminal(self, terminal):
-        self.use_terminal = terminal
+        self.add_action( OpenPathProgramAction(command, False), True )
+        self.add_action( OpenPathProgramAction(command, True) )
         
     def get_hash(self, text=None):
-        if not self.use_terminal:
-            return text
-        else:
-            return text+"_terminal"
+        return text
         
 class ProgramsHandler(deskbar.interfaces.Module):
     
@@ -233,11 +242,9 @@ class ProgramsHandler(deskbar.interfaces.Module):
         self._emit_query_ready(query, result )
         
     def query_path_programs(self, query):
-        args = query.split(" ")
-        match = self._check_program(args[0])
-
-        if match != None:
-            return [match]
+        program = query.split(" ")[0]
+        if is_program_in_path(program):
+            return [PathProgramMatch(program, query)]
         else:
             return []
     
@@ -247,38 +254,25 @@ class ProgramsHandler(deskbar.interfaces.Module):
             match._priority = get_priority_for_name(query, match._desktop.get_string("Exec"))
             result.append(match)
         return result
-            
-    
-    def on_key_press(self, query, shortcut):
-        if shortcut == gtk.keysyms.t:
-            match = self._check_program(query.split(" ")[0])
-            if match != None:
-                match.set_with_terminal(True)
-                return match
-            
-        return None
-        
-    def _check_program(self, program):
-        if is_program_in_path(program):
-            return PathProgramMatch(program)
                 
     def _scan_desktop_files(self):
         for dir in get_xdg_data_dirs():
-            for f in glob.glob(join(dir, "applications", "*.desktop")):
-                result = parse_desktop_file(f)
-                if result != None:
-                    match = GenericProgramMatch(
-                                name=result.get_localestring(deskbar.core.gnomedesktop.KEY_NAME),
-                                icon=result.get_string(deskbar.core.gnomedesktop.KEY_ICON),
-                                desktop=result,
-                                desktop_file=f)
-                    self._indexer.add("%s %s %s %s %s" % (
-                                result.get_string("Exec"),
-                                result.get_localestring(deskbar.core.gnomedesktop.KEY_NAME),
-                                result.get_localestring(deskbar.core.gnomedesktop.KEY_COMMENT),
-                                result.get_string(deskbar.core.gnomedesktop.KEY_NAME),
-                                result.get_string(deskbar.core.gnomedesktop.KEY_COMMENT),
-                            ), match)
+            for root, dirs, files in os.walk( join(dir, "applications") ):
+                for f in glob.glob( join(root, "*.desktop") ):
+                    result = parse_desktop_file(f)
+                    if result != None:
+                        match = GenericProgramMatch(
+                                    name=result.get_localestring(deskbar.core.gnomedesktop.KEY_NAME),
+                                    icon=result.get_string(deskbar.core.gnomedesktop.KEY_ICON),
+                                    desktop=result,
+                                    desktop_file=f)
+                        self._indexer.add("%s %s %s %s %s" % (
+                                    result.get_string("Exec"),
+                                    result.get_localestring(deskbar.core.gnomedesktop.KEY_NAME),
+                                    result.get_localestring(deskbar.core.gnomedesktop.KEY_COMMENT),
+                                    result.get_string(deskbar.core.gnomedesktop.KEY_NAME),
+                                    result.get_string(deskbar.core.gnomedesktop.KEY_COMMENT),
+                                ), match)
 
 def get_priority_for_name(query, name):
     if name.split(" ")[0].endswith(query):
